==> haskell-ghc-typelits-natnormalise-0.7.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-typelits-natnormalise
version:              0.7.2
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.2-9ii5fV5IEcy28FYv2fTw1e
key:                  ghc-typelits-natnormalise-0.7.2-9ii5fV5IEcy28FYv2fTw1e
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  64a27c248d92bdc9636ee6fefbd2766e
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-8.8.3/site-local/ghc-typelits-natnormalise-0.7.2

library-dirs:
    /usr/lib/ghc-8.8.3/site-local/ghc-typelits-natnormalise-0.7.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/ghc-typelits-natnormalise-0.7.2

hs-libraries:         HSghc-typelits-natnormalise-0.7.2-9ii5fV5IEcy28FYv2fTw1e
depends:
    base-4.13.0.0 containers-0.6.2.1 ghc-8.8.3
    ghc-tcplugins-extra-0.3.2-GsNmygbk7NUGCrqSFBjpGw
    integer-gmp-1.0.2.0 syb-0.7.1-HZot41yU46FEB2GjLEhNpM
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-natnormalise-0.7.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-typelits-natnormalise
version:              0.7.2
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.2-AjXe72Cjkk47R58J8QDd7D
key:                  ghc-typelits-natnormalise-0.7.2-AjXe72Cjkk47R58J8QDd7D
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  bd724350e5c01b3f48fc57750e74d8a1
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-8.8.3/site-local/ghc-typelits-natnormalise-0.7.2

library-dirs:
    /usr/lib/ghc-8.8.3/site-local/ghc-typelits-natnormalise-0.7.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/ghc-typelits-natnormalise-0.7.2

hs-libraries:         HSghc-typelits-natnormalise-0.7.2-AjXe72Cjkk47R58J8QDd7D
depends:
    base-4.13.0.0 containers-0.6.2.1 ghc-8.8.3
    ghc-tcplugins-extra-0.3.2-GsNmygbk7NUGCrqSFBjpGw
    integer-gmp-1.0.2.0 syb-0.7.1-HZot41yU46FEB2GjLEhNpM
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
